import networkx as nx
import numpy as np
import matplotlib.pyplot as plt

np.random.seed(1234)

ps = [0.0, 0.001, 0.01, 0.1, 1.0]
l = len(ps)

n = 500
k = 4

ns = np.arange(n)
thetas = 2*np.pi*ns/n + np.pi/2

pos = {}

for i,theta in zip(ns,thetas):
    pos[i] = [theta,0.9]

thetas = np.append(thetas, thetas[0])

fig = plt.figure(figsize=(5*l, 5))

for idx,p in enumerate(ps):

    ax = fig.add_subplot(1, l, idx+1, projection='polar')

    G = nx.connected_watts_strogatz_graph(n, k, p, seed=np.random)
    nx.draw_networkx_edges(G, pos=pos, ax=ax, node_size=10, node_color='black', with_labels=False, width=1-0.9*p)

    A = np.array(nx.adjacency_matrix(G).todense())
    w,v = np.linalg.eigh(A)
    u = np.abs(v[:,-1])
    u = u / np.linalg.norm(u)
    u = np.append(u, u[0])

    ax.plot(thetas, 3*np.abs(u)+1, color='black')
    ax.plot(thetas, 3*np.ones(n+1)/np.sqrt(n)+1, color='red', linestyle='--')
    ax.set_ylim([0.0, 2.0])
    ax.annotate(f'p={p}', xy=(-np.pi/2,1.8), fontsize='xx-large', ha='center')

    ax.axis('off')

fig.tight_layout()

fig.savefig('ws-centralities.pdf')
